summaryrefslogtreecommitdiff
path: root/public/js/render.js
diff options
context:
space:
mode:
Diffstat (limited to 'public/js/render.js')
-rw-r--r--public/js/render.js12
1 files changed, 11 insertions, 1 deletions
diff --git a/public/js/render.js b/public/js/render.js
index 46489247..860f8272 100644
--- a/public/js/render.js
+++ b/public/js/render.js
@@ -19,8 +19,18 @@ whiteList['style'] = []
whiteList['kbd'] = []
// allow ifram tag with some safe attributes
whiteList['iframe'] = ['allowfullscreen', 'name', 'referrerpolicy', 'sandbox', 'src', 'width', 'height']
-// allow summary tag
+// allow details tag
+whiteList['details'] = []
+// allow summary tag for details
whiteList['summary'] = []
+// allow ruby tag
+whiteList['ruby'] = []
+// allow rt tag for ruby
+whiteList['rt'] = []
+// allow figure tag
+whiteList['figure'] = []
+// allow figcaption tag
+whiteList['figcaption'] = []
var filterXSSOptions = {
allowCommentTag: true,